#ifndef NT2_INCLUDE_FUNCTIONS_AMUL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_AMUL_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/amul.hpp>

#endif
